import { core, flags, SfdxCommand } from "@salesforce/command";
import * as rimraf from "rimraf";
import { SFPowerkit } from "../../../sfpowerkit";
import ScratchOrgImpl from "../../../impl/pool/scratchorg/poolCreateImpl";
import { SfdxError } from "@salesforce/core";
// Initialize Messages with the current plugin directory
core.Messages.importMessagesDirectory(__dirname);
// Load the specific messages for this file. Messages from @salesforce/command, @salesforce/core,
// or any library that is using the messages framework can also be loaded this way.
const messages = core.Messages.loadMessages("sfpowerkit", "scratchorg_pool_create");
export default class Create extends SfdxCommand {
    async run() {
        rimraf.sync("temp_sfpowerkit");
        SFPowerkit.setLogLevel(this.flags.loglevel, false);
        await this.hubOrg.refreshAuth();
        const hubConn = this.hubOrg.getConnection();
        this.flags.apiversion =
            this.flags.apiversion || (await hubConn.retrieveMaxApiVersion());
        let scratchOrgPoolImpl = new ScratchOrgImpl(this.flags.configfilepath, this.hubOrg, this.flags.apiversion);
        try {
            await scratchOrgPoolImpl.poolScratchOrgs();
            return 1;
        }
        catch (err) {
            throw new SfdxError("Unable to execute command .. " + err);
        }
    }
}
Create.description = messages.getMessage("commandDescription");
Create.requiresDevhubUsername = true;
Create.examples = [
    `$ sfdx sfpowerkit:pool:create -f config\\core_poolconfig.json`,
    `$ sfdx sfpowerkit:pool:create -f config\\core_poolconfig.json -v devhub`
];
Create.flagsConfig = {
    configfilepath: flags.filepath({
        char: "f",
        description: messages.getMessage("configFilePathDescription"),
        required: true
    }),
    loglevel: flags.enum({
        description: "logging level for this command invocation",
        default: "info",
        required: false,
        options: [
            "trace",
            "debug",
            "info",
            "warn",
            "error",
            "fatal",
            "TRACE",
            "DEBUG",
            "INFO",
            "WARN",
            "ERROR",
            "FATAL"
        ]
    })
};
//# sourceMappingURL=create.js.map