import * as _ from "lodash";
import { METADATA_INFO } from "../metadataInfo";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import MetadataFiles from "../metadataFiles";
const QUERY = "Select Id, NamespacePrefix, DeveloperName, Label From CustomApplication ";
export default class CustomApplicationRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!CustomApplicationRetriever.instance) {
            CustomApplicationRetriever.instance = new CustomApplicationRetriever(org);
        }
        return CustomApplicationRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let apps = await super.getObjects();
            for (let i = 0; i < apps.length; i++) {
                let app = apps[i];
                if (!_.isNil(app.NamespacePrefix)) {
                    app.FullName = `${app.NamespacePrefix}__${app.DeveloperName}`;
                }
                else {
                    app.FullName = app.DeveloperName;
                }
            }
            this.data = apps;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getApps() {
        return await this.getObjects();
    }
    async appExists(application) {
        let found = false;
        //Look first in project files
        if (!_.isNil(METADATA_INFO.CustomApplication.components)) {
            found = METADATA_INFO.CustomApplication.components.includes(application);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let apps = await this.getApps();
            let foundApp = apps.find(app => {
                return app.FullName === application;
            });
            found = !_.isNil(foundApp);
        }
        return found;
    }
}
//# sourceMappingURL=customApplicationRetriever.js.map