import * as _ from "lodash";
import { METADATA_INFO } from "../metadataInfo";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import MetadataFiles from "../metadataFiles";
const QUERY = "SELECT Id, DeveloperName, NamespacePrefix From CustomPermission";
export default class CustomPermissionRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org, false);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!CustomPermissionRetriever.instance) {
            CustomPermissionRetriever.instance = new CustomPermissionRetriever(org);
        }
        return CustomPermissionRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            super.setQuery(QUERY);
            let customPermissions = await super.getObjects();
            for (let i = 0; i < customPermissions.length; i++) {
                let cp = customPermissions[i];
                if (!_.isNil(cp.NamespacePrefix)) {
                    cp.FullName = `${cp.NamespacePrefix}__${cp.DeveloperName}`;
                }
                else {
                    cp.FullName = cp.DeveloperName;
                }
            }
            this.data = customPermissions;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getCustomPermissions() {
        return await this.getObjects();
    }
    async customPermissionExists(customPermissionStr) {
        let found = false;
        //Look first in project files
        if (!_.isNil(METADATA_INFO.CustomPermission.components)) {
            found = METADATA_INFO.CustomPermission.components.includes(customPermissionStr);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let custumPermissions = await this.getCustomPermissions();
            let foundCp = custumPermissions.find(customPermission => {
                return customPermission.FullName === customPermissionStr;
            });
            found = !_.isNil(foundCp);
        }
        return found;
    }
}
//# sourceMappingURL=customPermissionRetriever.js.map