import * as _ from "lodash";
import { METADATA_INFO } from "../metadataInfo";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import MetadataFiles from "../metadataFiles";
const QUERY = "SELECT Id, MasterLabel, FullName  From Flow";
export default class FlowRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org, true);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!FlowRetriever.instance) {
            FlowRetriever.instance = new FlowRetriever(org);
        }
        return FlowRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            let flows = await this.retrieveFlows();
            this.data = flows;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async retrieveFlows() {
        const apiversion = await this.org.retrieveMaxApiVersion();
        let toReturn = new Promise((resolve, reject) => {
            this.org
                .getConnection()
                .metadata.list([{ type: "Flow", folder: null }], apiversion, function (err, metadata) {
                if (err) {
                    return reject(err);
                }
                let flowsObjList = [];
                for (let i = 0; i < metadata.length; i++) {
                    let flow = {
                        FullName: metadata[i].fullName,
                        NamespacePrefix: metadata[i].namespacePrefix,
                        Id: ""
                    };
                    if (metadata[i].namespacePrefix !== "" &&
                        metadata[i].namespacePrefix !== undefined) {
                        flow.FullName = `${metadata[i].namespacePrefix}__${metadata[i].fullName}`;
                    }
                    flowsObjList.push(flow);
                }
                resolve(flowsObjList);
            });
        });
        return toReturn;
    }
    async getFlows() {
        return await this.getObjects();
    }
    async flowExists(flowStr) {
        let found = false;
        //Look first in project files
        if (!_.isNil(METADATA_INFO.Flow.components)) {
            found = METADATA_INFO.Flow.components.includes(flowStr);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let flows = await this.getFlows();
            let foundFlow = flows.find(flow => {
                return flow.FullName === flowStr;
            });
            found = !_.isNil(foundFlow);
        }
        return found;
    }
}
//# sourceMappingURL=flowRetriever.js.map