import { METADATA_INFO } from "../metadataInfo";
import * as _ from "lodash";
import BaseMetadataRetriever from "./baseMetadataRetriever";
import MetadataFiles from "../metadataFiles";
const QUERY = "Select Id, Name, DeveloperName, SobjectType, NamespacePrefix from RecordType";
export default class RecordTypeRetriever extends BaseMetadataRetriever {
    constructor(org) {
        super(org);
        this.org = org;
        super.setQuery(QUERY);
    }
    static getInstance(org) {
        if (!RecordTypeRetriever.instance) {
            RecordTypeRetriever.instance = new RecordTypeRetriever(org);
        }
        return RecordTypeRetriever.instance;
    }
    async getObjects() {
        if ((this.data === undefined || this.data.length == 0) &&
            !this.dataLoaded) {
            let objects = await super.getObjects();
            objects = objects.map(elem => {
                let namespace = "";
                if (elem.NamespacePrefix !== undefined &&
                    elem.NamespacePrefix !== "" &&
                    elem.NamespacePrefix !== null &&
                    elem.NamespacePrefix !== "null") {
                    namespace = elem.NamespacePrefix + "__";
                }
                elem.FullName = elem.SobjectType + "." + namespace + elem.DeveloperName;
                if (elem.DeveloperName === "PersonAccount" &&
                    elem.SobjectType === "Account") {
                    elem.FullName =
                        "PersonAccount" + "." + namespace + elem.DeveloperName;
                }
                return elem;
            });
            this.data = objects;
            this.dataLoaded = true;
        }
        return this.data;
    }
    async getrecordTypes() {
        return await this.getObjects();
    }
    async recordTypeExists(recordType) {
        let found = false;
        //Look first in project files
        if (!_.isNil(METADATA_INFO.RecordType.components)) {
            found = METADATA_INFO.RecordType.components.includes(recordType);
        }
        if (!found && !MetadataFiles.sourceOnly) {
            //not found, check on the org
            let recordTypes = await this.getrecordTypes();
            let foundRecordType = recordTypes.find(rt => {
                return rt.FullName === recordType;
            });
            found = !_.isNil(foundRecordType);
        }
        return found;
    }
}
//# sourceMappingURL=recordTypeRetriever.js.map